"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayerSetHostEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player becomes the host of the room.
 *
 * This event contains a `setHost` method that does not do anything in SkeldJS
 * as the host of the room is decided by the server, making it impossible to alter
 * the host as a client.
 *
 * A server implementation may implement this by overriding the functions in
 * {@link Hostable} responsible for updating the host.
 */
class PlayerSetHostEvent extends events_1.BasicEvent {
    constructor(room, player) {
        super();
        this.room = room;
        this.player = player;
        this.eventName = "player.sethost";
        this._alteredHost = player;
    }
    /**
     * The altered player that will be made host instead, if changed.
     */
    get alteredHost() {
        return this._alteredHost;
    }
    /**
     * Change the player that was made host.
     * @param player The player to make host.
     */
    setHost(player) {
        this._alteredHost = player;
    }
}
exports.PlayerSetHostEvent = PlayerSetHostEvent;
PlayerSetHostEvent.eventName = "player.sethost";
//# sourceMappingURL=SetHost.js.map