"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReactorConsoleRemoveEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player places their hand on a reactor console.
 */
class ReactorConsoleRemoveEvent extends events_1.RevertableEvent {
    constructor(room, reactor, message, 
    /**
     * The player that removed their hand from the console. Only available
     * if the client is the host.
     */
    player, consoleId) {
        super();
        this.room = room;
        this.reactor = reactor;
        this.message = message;
        this.player = player;
        this.consoleId = consoleId;
        this.eventName = "reactor.consoles.remove";
        this._alteredConsoleId = consoleId;
    }
    /**
     * The ID of the altered console that will be removed instead, if changed.
     */
    get alteredConsoleId() {
        return this._alteredConsoleId;
    }
    /**
     * Change the console that the player removed their hand from.
     * @param consoleId The ID of the console to set.
     */
    setConsole(consoleId) {
        this._alteredConsoleId = consoleId;
    }
}
exports.ReactorConsoleRemoveEvent = ReactorConsoleRemoveEvent;
ReactorConsoleRemoveEvent.eventName = "reactor.consoles.remove";
//# sourceMappingURL=ConsoleRemove.js.map